from setuptools import setup, find_packages

setup(
    name="semantik-sdk",
    version="0.1.2",
    packages=find_packages(),
    install_requires=[
        "requests>=2.31.0",
    ],
    python_requires=">=3.8",
)

